@@ -25,7 +25,8 @@ REMEDIATION_TO_EXT_MAP = {
     'puppet': '.pp',
     'ignition': '.yml',
     'kubernetes': '.yml',
-    'blueprint': '.toml'
+    'blueprint': '.toml',
+    'kickstart': '.cfg'
 }
 
 
@@ -145,6 +146,14 @@ class Remediation(object):
                 if p not in inherited_cpe_platform_names}
         return rule_specific_cpe_platform_names
 
+    def _get_stripped_conditional(self, language, platform):
+        conditional = platform.get_remediation_conditional(language)
+        if conditional is not None:
+            stripped_conditional = conditional.strip()
+            if stripped_conditional:
+                return stripped_conditional
+        return None
+
     def get_stripped_conditionals(self, language, cpe_platform_names, cpe_platforms):
         """
         collect conditionals of platforms defined by cpe_platform_names
@@ -152,11 +161,10 @@ class Remediation(object):
         """
         stripped_conditionals = []
         for p in cpe_platform_names:
-            conditional = cpe_platforms[p].get_remediation_conditional(language)
-            if conditional is not None:
-                stripped_conditional = conditional.strip()
-                if stripped_conditional:
-                    stripped_conditionals.append(stripped_conditional)
+            platform = cpe_platforms[p]
+            maybe_stripped_conditional = self._get_stripped_conditional(language, platform)
+            if maybe_stripped_conditional is not None:
+                stripped_conditionals.append(maybe_stripped_conditional)
         return stripped_conditionals
 
     def get_rule_specific_conditionals(self, language, cpe_platforms):
@@ -218,10 +226,10 @@ class BashRemediation(Remediation):
         if stripped_fix_text == "":
             return result
 
-        inherited_conditionals = super(
-            BashRemediation, self).get_inherited_conditionals("bash", cpe_platforms)
-        rule_specific_conditionals = super(
-            BashRemediation, self).get_rule_specific_conditionals("bash", cpe_platforms)
+        inherited_conditionals = sorted(super(
+            BashRemediation, self).get_inherited_conditionals("bash", cpe_platforms))
+        rule_specific_conditionals = sorted(super(
+            BashRemediation, self).get_rule_specific_conditionals("bash", cpe_platforms))
         if inherited_conditionals or rule_specific_conditionals:
             wrapped_fix_text = ["# Remediation is applicable only in certain platforms"]
 
@@ -324,11 +332,8 @@ class AnsibleRemediation(Remediation):
         return result
 
     def _get_rule_reference(self, ref_class):
-        refs = self.associated_rule.references.get(ref_class, "")
-        if refs:
-            return refs.split(",")
-        else:
-            return []
+        refs = self.associated_rule.references.get(ref_class, [])
+        return refs
 
     def inject_package_facts_task(self, parsed_snippet):
         """ Injects a package_facts task only if
@@ -355,16 +360,18 @@ class AnsibleRemediation(Remediation):
                     has_ansible_facts_packages_clause = True
 
         if has_ansible_facts_packages_clause and not has_package_facts_task:
-            facts_task = OrderedDict({'name': 'Gather the package facts',
-                                      'package_facts': {'manager': 'auto'}})
+            facts_task = OrderedDict([
+                ('name', 'Gather the package facts'),
+                ('package_facts', {'manager': 'auto'})
+            ])
             parsed_snippet.insert(0, facts_task)
 
     def update_when_from_rule(self, to_update, cpe_platforms):
         additional_when = []
-        inherited_conditionals = super(
-            AnsibleRemediation, self).get_inherited_conditionals("ansible", cpe_platforms)
-        rule_specific_conditionals = super(
-            AnsibleRemediation, self).get_rule_specific_conditionals("ansible", cpe_platforms)
+        inherited_conditionals = sorted(super(
+            AnsibleRemediation, self).get_inherited_conditionals("ansible", cpe_platforms))
+        rule_specific_conditionals = sorted(super(
+            AnsibleRemediation, self).get_rule_specific_conditionals("ansible", cpe_platforms))
         # Remove conditionals related to package CPEs if the updated task collects package facts
         if "package_facts" in to_update:
             inherited_conditionals = filter(
@@ -452,6 +459,15 @@ class BlueprintRemediation(Remediation):
             file_path, "blueprint")
 
 
+class KickstartRemediation(Remediation):
+    """
+    This provides class for Kickstart remediations
+    """
+    def __init__(self, file_path):
+        super(KickstartRemediation, self).__init__(
+            file_path, "kickstart")
+
+
 REMEDIATION_TO_CLASS = {
     'anaconda': AnacondaRemediation,
     'ansible': AnsibleRemediation,
@@ -460,6 +476,7 @@ REMEDIATION_TO_CLASS = {
     'ignition': IgnitionRemediation,
     'kubernetes': KubernetesRemediation,
     'blueprint': BlueprintRemediation,
+    'kickstart': KickstartRemediation,
 }
 
 
@@ -597,7 +614,8 @@ def expand_xccdf_subs(fix, remediation_type):
 
     elif remediation_type == "bash":
         pattern = r'\(bash-populate\s*(\S+)\)'
-
+    elif remediation_type == "kickstart":
+        pattern = r'\(kickstart-populate\s*(\S+)\)'
     else:
         sys.stderr.write("Unknown remediation type '%s'\n" % (remediation_type))
         sys.exit(1)
